==> pochy-0.1.2b-src.tar.gz: pochy-0.1.2b-src/DraftFrame.h <==
#if !defined(AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_)
#define AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DraftFrame.h : wb_[ t@C
//
#include "Pochy.h"
#include "splitex.h"
#include "MailEditView.h"
#include "AttachedFileView.h"
#include "ProgDialog.h"
#include "MimeEncode.h"
#include "AddressView.h"
#include "DraftSendDlg.h"

/////////////////////////////////////////////////////////////////////////////
// CDraftFrame t[

class CDraftFrame : public CFrameWnd
{
	DECLARE_DYNCREATE(CDraftFrame)
protected:
	CDraftFrame();           // IɎgpveNg RXgN^B

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDraftFrame)
	public:
	protected:
	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CDraftFrame();

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDraftFrame)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnSend();
	afx_msg void OnSaveToDraft();
	afx_msg void OnAddFile();
	afx_msg void OnExtEditor();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnUpdateSend(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpg(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpgEnc(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpgExp(CCmdUI* pCmdUI);
	afx_msg void OnUpdateAddFile(CCmdUI* pCmdUI);
	afx_msg void OnUpdateAddress(CCmdUI* pCmdUI);
	afx_msg void OnUpdateSaveDraft(CCmdUI* pCmdUI);
	afx_msg void OnUpdateExtEditor(CCmdUI* pCmdUI);
	afx_msg void OnGpgEnc();
	afx_msg void OnAddress();
	afx_msg void OnGpg();
	afx_msg void OnGpgExport();
	afx_msg void OnClose();
	afx_msg void OnDestroy();
	afx_msg void OnToolbarDropDown(NMTOOLBAR* pnmh, LRESULT* plRes);
	afx_msg void OnChangeBkColorDraft();
	afx_msg void OnChangeTxtColorDraft();
	afx_msg void OnGpgKeyManagement();
	//}}AFX_MSG
	afx_msg void OnEnd();
	afx_msg void OnProgCreate();
	afx_msg void OnProgDestroy();
	afx_msg void OnGetMinMaxInfo( MINMAXINFO FAR* lpMMI );
	DECLARE_MESSAGE_MAP()
protected:
	BOOL CreateToolbar();
	CToolBar m_wndToolBar;
public:
	void DisableButton(BOOL b);
	CString m_account;
	void HideAttachedFileView(BOOL b);
	void ReArrangeSplit();
	BOOL SaveToDraft(BOOL confirm);
	void AttachFileFromCxCi();
	CStatusBar	m_wndStatusBar;
	CSplitterWndEx m_wndSplit;
	CSplitterWndEx m_wndSplit1;
	BOOL m_hide;
	BOOL m_hide2;
	BOOL m_hide_attach;
	BOOL m_flag;
	BOOL m_ime_status;
	BOOL m_button_gpgenc;
	BOOL m_button_gpgexp;
	BOOL m_button_addfile;
	BOOL m_button_sendmail;
	BOOL m_button_address;
	BOOL m_button_savedraft;
	BOOL m_button_exteditor;
	BOOL m_button_gpg;
	CMimeEncode m_me;
	CAddressView* m_pAddrsV;
	CMailEditView* m_pEditV;		// for mail editing
	CAttachedFileView* m_pListV2;	// for displaying attached file
	CStringArray m_attach;			// array list for Ytt@C̃pXۑz
	CProgDialog m_pd;				// vOXo[
	void SwitchView();
	void CloseIME(CView* view);
	void RecoverIME(CView* view);
	void SetStatusBarText(int pane, LPSTR buf);
	BOOL Char(UINT nChar,CView* view);
	BOOL KeyDown(UINT nChar,CView* view);
	CDraftSendDlg* m_send_dlg;
};

/////////////////////////////////////////////////////////////////////////////
//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_)

==> pochy-0.2-src.tar.gz: pochy-0.2-src/DraftFrame.h <==
#if !defined(AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_)
#define AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DraftFrame.h : wb_[ t@C
//
#include "Pochy.h"
#include "splitex.h"
#include "MailEditView.h"
#include "AttachedFileView.h"
#include "ProgDialog.h"
#include "MimeEncode.h"
#include "AddressView.h"
#include "DraftSendDlg.h"
#include "AcceleratorTable.h"

/////////////////////////////////////////////////////////////////////////////
// CDraftFrame t[

class CDraftFrame : public CFrameWnd
{
	DECLARE_DYNCREATE(CDraftFrame)
protected:
	CDraftFrame();           // IɎgpveNg RXgN^B

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDraftFrame)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CDraftFrame();

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDraftFrame)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnSend();
	afx_msg void OnSaveToDraft();
	afx_msg void OnAddFile();
	afx_msg void OnExtEditor();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnUpdateSend(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpg(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpgEnc(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpgExp(CCmdUI* pCmdUI);
	afx_msg void OnUpdateAddFile(CCmdUI* pCmdUI);
	afx_msg void OnUpdateAddress(CCmdUI* pCmdUI);
	afx_msg void OnUpdateSaveDraft(CCmdUI* pCmdUI);
	afx_msg void OnUpdateExtEditor(CCmdUI* pCmdUI);
	afx_msg void OnGpgEnc();
	afx_msg void OnAddress();
	afx_msg void OnGpg();
	afx_msg void OnGpgExport();
	afx_msg void OnClose();
	afx_msg void OnDestroy();
	afx_msg BOOL OnToolbarDropDown(NMHDR *pNMHDR, LRESULT* plRes);
	afx_msg void OnChangeBkColorDraft();
	afx_msg void OnChangeTxtColorDraft();
	afx_msg void OnGpgKeyManagement();
	afx_msg BOOL OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	//}}AFX_MSG
	afx_msg void OnEnd();
	afx_msg void OnProgCreate();
	afx_msg void OnProgDestroy();
	afx_msg void OnGetMinMaxInfo( MINMAXINFO FAR* lpMMI );
	DECLARE_MESSAGE_MAP()
protected:
	BOOL CreateToolbar();
	CToolBar m_wndToolBar;
public:
	void SetAcceleratorTargetWindow();
	void LoadDefaultAccelerator();
	void LoadAccelerator();
	void DisableButton(BOOL b);
	CString m_account;
	void HideAttachedFileView(BOOL b);
	void ReArrangeSplit();
	BOOL SaveToDraft(BOOL confirm);
	void AttachFileFromCxCi();
	CStatusBar	m_wndStatusBar;
	CSplitterWndEx m_wndSplit;
	CSplitterWndEx m_wndSplit1;
	BOOL m_hide;
	BOOL m_hide2;
	BOOL m_hide_attach;
	BOOL m_flag;
	BOOL m_ime_status;
	BOOL m_button_gpgenc;
	BOOL m_button_gpgexp;
	BOOL m_button_addfile;
	BOOL m_button_sendmail;
	BOOL m_button_address;
	BOOL m_button_savedraft;
	BOOL m_button_exteditor;
	BOOL m_button_gpg;
	CStringArray m_key_id_list;
	CMimeEncode m_me;
	CAddressView* m_pAddrsV;
	CMailEditView* m_pEditV;		// for mail editing
	CAttachedFileView* m_pListV2;	// for displaying attached file
	CStringArray m_attach;			// array list for Ytt@C̃pXۑz
	CProgDialog m_pd;				// vOXo[
	void OnSwitchView();
	void CloseIME(CView* view);
	void RecoverIME(CView* view);
	void SetStatusBarText(int pane, LPSTR buf);
	BOOL Char(UINT nChar,CView* view);
	BOOL KeyDown(UINT nChar,CView* view);
	CDraftSendDlg* m_send_dlg;
private:
	CAcceleratorTable m_acceleratorTable;
};

/////////////////////////////////////////////////////////////////////////////
//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DRAFTFRAME_H__5D540EA0_4849_11D5_B88F_00008659960F__INCLUDED_)
